@@ -17,16 +17,22 @@
 
 import os
 
+DEFAULTS = {
+    'IUNO_CLOUD_STORAGE_GOOGLE_CREDENTIAL': os.path.join(os.path.dirname(
+        os.path.realpath(__file__)), 'gos', '.credentials', 'credential.json'),
+    'IUNO_CLOUD_STORAGE_GOOGLE_SCOPE': 'https://www.googleapis.com/auth/drive'
+}
+
 
 def attachSettings(settingsLocals, backends, preferred, config):
     """
     Attach 'storage' related settings to settings.py.
 
     @param settingsLocals locals() in settings.py.
+    @param backends Backend instances.
+    @param preferred Preferred backends.
+    @param config Configuration settings.
     """
-    settingsLocals.update({
-        'CLOUD_STORAGE_GOOGLE_SECRET': os.path.join(os.path.dirname(
-            os.path.realpath(__file__)), 'gos', 'client_secret.json'),
-        'CLOUD_STORAGE_GOOGLE_SCOPE': 'https://www.googleapis.com/auth/drive',
-        'CLOUD_STORAGE_GOOGLE_APP_NAME': 'Drive API Python Quickstart'
-    })
+
+    for key, val in DEFAULTS.items():
+        settingsLocals.setdefault(key, val)
